# PyMoX-Kit

<div style="display: flex; justify-content: center; align-items: center; gap: 7px;margin-bottom: 12px">
  <span>Trousse à <b>outils utiles pour devs en</b></span>
  <a href="https://pymox.fr" target="_blank" rel="noopener noreferrer">
    <img src="https://pymox.fr/assets/images/pymox_logo_tr_001.png" title="Visiter le site Web !" width="70">
  </a>
</div>

![OS Support](https://img.shields.io/badge/OS-Windows_&_Linux-0078D6)
![WinSxS Ready](https://img.shields.io/badge/Windows-Ready-0078D6?logo=windows&logoColor=white)
![Linux Compatible](https://img.shields.io/badge/Linux-Compatible-FCC624?logo=linux&logoColor=#FCC624)
[![Python](https://img.shields.io/badge/Python-3.11→3.14-3776AB?logo=python)](https://www.python.org)
[![PyMox_FR](https://img.shields.io/github/v/tag/PyMoX-fr/PyMoX-fr.github.io?label=PyMoX.fr)](https://pymox.fr/outils/logs/CHANGELOG)
[![PyMoX-Kit Version](https://img.shields.io/pypi/v/pymox-kit?logo=python&logoColor=white&label=PyMoX-Kit)](https://pypi.org/project/pymox-kit)
[![GitHub Passing](https://img.shields.io/badge/GitHub-Passing-2ea44f?logo=github&logoColor=white)](https://github.com/PyMoX-fr/Kit)

---

## Installation

```bash
py -m venv .venv
.\.venv\Scripts\activate
py -m pip install --upgrade pip
pip install pymox_kit
```

## Utilisation

```python
from pytmox_kit import *

print(Hello())
```

## Contribution

Pour tester la lib **PyMox_Kit** : [![GitHub](https://img.shields.io/badge/GitHub-Dépôt_Test_Kit-2ea44f?logo=github&logoColor=white)](https://github.com/PyMoX-fr/Kit)

Si volonté d' ↑ la lib : → Merge Request [![GitHub Passing](https://img.shields.io/badge/GitHub-PyMox_Kit-2ea44f?logo=github&logoColor=white)](https://github.com/PyMoX-fr/Kit)

## Help

[![GitHub Issue](https://img.shields.io/badge/GitHub-PyMox_Kit_Issues-2ea44f?logo=github&logoColor=white)](https://github.com/PyMoX-fr/Kit/issues)
